/**
 * @description Wrap表单配置信息
 */
export default function (setting, list) {
  let roleList = sessionStorage.getItem('sysRoles')
  let appType = sessionStorage.getItem('appType')

  if (roleList) {
    try {
      roleList = JSON.parse(roleList)
    } catch (e) {
      roleList = []
    }
  } else {
    roleList = []
  }

  const settingForm = [
    {
      type: 'text',
      field: 'title',
      label: '标题',
      initval: setting.title || '',
      required: false
    },
    {
      type: 'text',
      field: 'name',
      label: '组件名称',
      initval: setting.name || '',
      tooltip: '用于组件间的区分。',
      required: true
    },
    {
      type: 'number',
      field: 'width',
      label: '宽度',
      initval: setting.width || 24,
      tooltip: '栅格布局，每行等分为24列。',
      min: 1,
      max: 24,
      precision: 0,
      required: true
    },
    {
      type: 'select',
      field: 'bindPropId',
      label: '显示状态绑定',
      initval: setting.bindPropId || '',
      tooltip: '分组可绑定设有空值隐藏的属性卡，当属性卡隐藏时分组一同隐藏。',
      required: false,
      options: list,
      forbid: appType === 'mob'
    },
    // {
    //   type: 'radio',
    //   field: 'print',
    //   label: '打印按钮',
    //   initval: setting.print || 'false',
    //   required: false,
    //   options: [
    //     {value: 'true', label: '显示'},
    //     {value: 'false', label: '隐藏'},
    //   ],
    //   controlFields: [
    //     {field: 'pageSize', values: ['true']},
    //     {field: 'pageLayout', values: ['true']},
    //     {field: 'hide', values: ['true']},
    //   ],
    //   forbid: appType === 'mob'
    // },
    // {
    //   type: 'radio',
    //   field: 'pageSize',
    //   label: '打印尺寸',
    //   initval: setting.pageSize || 'A4',
    //   required: true,
    //   options: [
    //     {value: 'A3', label: 'A3'},
    //     {value: 'A4', label: 'A4'},
    //     {value: 'A5', label: 'A5'},
    //   ],
    //   forbid: appType === 'mob'
    // },
    // {
    //   type: 'radio',
    //   field: 'pageLayout',
    //   label: '打印布局',
    //   initval: setting.pageLayout || 'vertical',
    //   required: true,
    //   options: [
    //     {value: 'vertical', label: '纵向'},
    //     {value: 'horizontal', label: '横向'},
    //   ],
    //   forbid: appType === 'mob'
    // },
    // {
    //   type: 'checkbox',
    //   field: 'hide',
    //   label: '隐藏元素',
    //   initval: setting.hide || [],
    //   tooltip: '执行打印时需要隐藏的页面元素。',
    //   required: false,
    //   options: [
    //     {value: 'search', label: '搜索'},
    //     {value: 'button', label: '按钮'},
    //   ],
    //   forbid: appType === 'mob'
    // },
    {
      type: 'radio',
      field: 'permission',
      label: '权限验证',
      initval: setting.permission || 'false',
      required: false,
      options: [
        {value: 'true', label: '启用'},
        {value: 'false', label: '禁用'},
      ],
      forbid: !appType || sessionStorage.getItem('editMenuType') === 'popview'
    },
    {
      type: 'radio',
      field: 'layout',
      label: '元素布局',
      initval: setting.layout || 'grid',
      tooltip: '分组中元素的排列方式',
      required: false,
      options: [
        {value: 'grid', label: '栅格布局'},
        {value: 'flex', label: '弹性布局'},
      ]
    },
    {
      type: 'radio',
      field: 'mergeAble',
      label: '展开/收起',
      initval: setting.mergeAble || 'false',
      tooltip: '启用时，组件右上角将出现展开/收起的图标，可将当前组件展开或收起。',
      required: false,
      options: [
        {value: 'true', label: '启用'},
        {value: 'false', label: '禁用'},
      ],
      controlFields: [
        {field: 'ctrlNumber', values: ['true']},
      ],
      forbid: appType === 'mob'
    },
    {
      type: 'number',
      field: 'ctrlNumber',
      label: '控制数',
      initval: setting.ctrlNumber || 1,
      tooltip: '当组件收起时，其后需要展开的组件数。',
      min: 1,
      max: 5,
      precision: 0,
      required: true,
      forbid: appType === 'mob'
    },
    {
      type: 'multiselect',
      field: 'blacklist',
      label: '黑名单',
      initval: setting.blacklist || [],
      required: false,
      options: roleList,
      forbid: !!appType
    },
  ]

  return settingForm
} 